@@ -5,6 +5,7 @@ import numpy as np
 import warnings
 import cv2
 import re
+import subprocess
 warnings.filterwarnings("ignore")
 
 def predark(img):
@@ -23,9 +24,8 @@ def upsacale(image,cvdnn_path):
 
 def inference(img_path,ocr,cvdnn_path):
     try:
-        macadd=gma()
-        uniqueadd =["60:e3:2b:34:66:ce","a8:7e:ea:41:ad:34","1c:69:7a:ae:44:32"]
-        if macadd in uniqueadd:
+        machineid = subprocess.run(['cat', '/etc/machine-id'], stdout=subprocess.PIPE)
+        if(machineid.stdout.decode('utf-8').rstrip() in ["4c44501bf7b14db9a99e21cc0fb0abfe"]):
             print("Configured Sucessfully")
             image= cv2.imread(img_path)
             img_path=upsacale(image,cvdnn_path)
